@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,8 +16,12 @@
 #include <KCrash>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/pimdataexporteduserfeedbackprovider.h"
+#ifdef USE_KUSERFEEDBACK_QT6
+#include <KUserFeedbackQt6/Provider>
+#else
 #include <KUserFeedback/Provider>
 #endif
+#endif
 
 int main(int argc, char *argv[])
 {
